%global debug_package   %{nil}
%global grafana_home    /usr/share/grafana

%global app_name grafana
%global app_version 6.4.4
%global oracle_release_version 1.0.1.dev

Name:               %{app_name}
Version:            %{app_version}
Release:            %{oracle_release_version}%{?dist}
Summary:            Grafana is an open source, feature rich metrics dashboard and graph editor
License:            ASL 2.0
URL:                https://github.com/grafana/grafana
Source:             %{name}-%{version}.tar.bz2
ExclusiveArch:      x86_64
Vendor:             Oracle America
BuildRequires:      golang >= 1.12.0
BuildRequires:      nodejs >= 10, nodejs < 11
BuildRequires:      nodejs-yarn >= 1.15.0

BuildRequires:      systemd

Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
Requires:           freetype-demos
Requires:           freetype-devel
Requires:           urw-fonts
Requires:           fontconfig

%description
Grafana is an open source, feature rich metrics dashboard and graph editor for
Graphite, InfluxDB & OpenTSDB.

%package -n grafana-docker-bin
Summary:            Grafana is an open source, feature rich metrics dashboard and graph editor. A Package for grafana binary installation in containers.
Requires:           fontconfig
Requires:           ca-certificates
Requires:           curl

%description -n grafana-docker-bin
Grafana is an open source, feature rich metrics dashboard and graph editor for
Graphite, InfluxDB & OpenTSDB.A Package for grafana binary installation in containers.

%prep
%setup -n %{name}-%{version}
cd %{_builddir}
mkdir -p src/github.com/grafana/
rm -rf src/github.com/grafana/%{name}
mv %{name}-%{version} src/github.com/grafana/grafana
ln -sf src/github.com/grafana/grafana %{name}-%{version}

%build -n src/github.com/grafana/grafana
export GOPATH=%{_builddir}
nodejs-yarn install --pure-lockfile
npm run build
go run build.go -goos linux -pkg-arch amd64 ${OPT} build pkg-archive latest
mkdir -p _output/bin/
cp dist/grafana-latest.linux-x64.tar.gz _output/bin/grafana.tar.gz
cp packaging/docker/run.sh _output/bin/
mkdir _output/bin/grafana
tar xfvz _output/bin/grafana.tar.gz --strip-components=1 -C _output/bin/grafana

%install
cd %{_builddir}/src/github.com/grafana/grafana
install -d -p %{buildroot}%{_datadir}/%{name}
cp -rp _output/bin/grafana %{buildroot}/usr/share/
install -p -m 644 -t %{buildroot}%{grafana_home} _output/bin/run.sh
cp -pav *.md %{buildroot}%{_datadir}/%{name}
cp -rpav docs %{buildroot}%{_datadir}/%{name}
install -d -p %{buildroot}%{_sbindir}
cp bin/*/%{name}-server %{buildroot}%{_sbindir}/
cp bin/*/%{name}-cli %{buildroot}%{_sbindir}/
install -d -p %{buildroot}%{_sysconfdir}/%{name}
cp conf/defaults.ini %{buildroot}%{_sysconfdir}/%{name}/grafana.ini
cp conf/ldap.toml %{buildroot}%{_sysconfdir}/%{name}/ldap.toml
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 packaging/rpm/systemd/grafana-server.service %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0644 packaging/rpm/sysconfig/grafana-server %{buildroot}%{_sysconfdir}/sysconfig
install -d -p %{buildroot}%{_sharedstatedir}/%{name}
install -d -p %{buildroot}/var/log/%{name}

%files -n grafana-docker-bin
%license LICENSE THIRD_PARTY_LICENSES.txt
%attr(-, root, root) %{_datadir}/%{name}
%exclude %{_datadir}/%{name}/*.md
%exclude %{_datadir}/%{name}/docs
%attr(-, root, root) %doc %{_datadir}/%{name}/CHANGELOG.md
%attr(-, root, root) %doc %{_datadir}/%{name}/NOTICE.md
%attr(-, root, root) %doc %{_datadir}/%{name}/README.md
%attr(-, root, root) %doc %{_datadir}/%{name}/ROADMAP.md
%attr(-, root, root) %doc %{_datadir}/%{name}/docs

%files -n grafana
%license LICENSE THIRD_PARTY_LICENSES.txt
%attr(0755, root, root) %{_sbindir}/%{name}-server
%attr(0755, root, root) %{_sbindir}/%{name}-cli
%attr(0755, root, grafana) %dir %{_sysconfdir}/%{name}
%attr(0640, root, grafana) %{_sysconfdir}/%{name}/grafana.ini
%attr(0640, root, grafana) %{_sysconfdir}/%{name}/ldap.toml
%attr(0755, grafana, grafana) %dir %{_sharedstatedir}/%{name}
%attr(0755, grafana, grafana) %dir /var/log/%{name}
%attr(-, root, root) %{_unitdir}/grafana-server.service
%attr(-, root, root) %{_sysconfdir}/sysconfig/grafana-server
%attr(-, grafana, grafana) %{_datadir}/%{name}
%exclude %{_datadir}/%{name}/*.md
%exclude %{_datadir}/%{name}/docs
%attr(-, root, root) %doc %{_datadir}/%{name}/CHANGELOG.md
%attr(-, root, root) %doc %{_datadir}/%{name}/NOTICE.md
%attr(-, root, root) %doc %{_datadir}/%{name}/README.md
%attr(-, root, root) %doc %{_datadir}/%{name}/ROADMAP.md
%attr(-, root, root) %doc %{_datadir}/%{name}/docs

%clean
rm -rf src

%pre -n grafana
getent group grafana >/dev/null || groupadd -r -g 472 grafana
getent passwd grafana >/dev/null || \
    useradd -r -u 472 -g grafana -d /etc/grafana -s /sbin/nologin \
    -c "Grafana Dashboard" grafana
exit 0

%post -n grafana
%systemd_post grafana.service

%preun -n grafana
%systemd_preun grafana.service

%postun -n grafana
%systemd_postun grafana.service

%changelog
* Thu Jan 02 2020 Olcne-Builder Jenkins <olcne-builder_us@oracle.com> - %{$version}-%{oracle_release_version}
- Added Oracle Specific Build Files for grafana
